@@ -1,6 +1,6 @@
 package Hubot::Scripts::Bundle;
 {
-  $Hubot::Scripts::Bundle::VERSION = '0.0.5';
+  $Hubot::Scripts::Bundle::VERSION = '0.0.6';
 }
 
 1;
@@ -23,7 +23,8 @@ example F<hubot-scripts.json>
         "ping",
         "uptime",
         "whisper",
-        "eval"
+        "eval",
+	    "tell"
     ]
 
 and then,
@@ -74,6 +75,17 @@ speak <text> behind hubot
 
 evaluate <code> and show the result via L<http://api.dan.co.jp/lleval.cgi>
 
+=item tell
+
+Tell Hubot to send a user a message when present in the room
+
+    me> hubot tell <user> <message>
+
+=item bugzilla
+
+    me> bug <id>|<keyword>
+    me> bug search <keyword>
+
 =back
 
 =head1 SEE ALSO
